Macro rcstr
rcstr!() { /* proc-macro */ }Expand description
Create an rcstr from a string literal.
Allocates the RcStr inline when possible, otherwise uses a static PrehashedString. In
either case this is a compile time constant
rcstr!() { /* proc-macro */ }Create an rcstr from a string literal.
Allocates the RcStr inline when possible, otherwise uses a static PrehashedString. In
either case this is a compile time constant