macro_rules! rcstr {
($s:expr) => { ... };
}Expand description
Create an rcstr from a string literal.
Allocates the RcStr inline when possible, otherwise uses a static PrehashedString. In either
case this is a compile time constant
macro_rules! rcstr {
($s:expr) => { ... };
}Create an rcstr from a string literal.
Allocates the RcStr inline when possible, otherwise uses a static PrehashedString. In either
case this is a compile time constant